@@ -216,23 +216,23 @@ Hyper::Functions
 
 =item Last changed by
 
-$Author: ac0v $
+$Author: $
 
 =item Id
 
-$Id: Context.pm 317 2008-02-16 01:52:33Z ac0v $
+$Id: $
 
 =item Revision
 
-$Revision: 317 $
+$Revision: $
 
 =item Date
 
-$Date: 2008-02-16 02:52:33 +0100 (Sa, 16 Feb 2008) $
+$Date: $
 
 =item HeadURL
 
-$HeadURL: http://svn.hyper-framework.org/Hyper/Hyper/branches/0.04/lib/Hyper/Config/Reader/Context.pm $
+$HeadURL: $
 
 =back
 
