@@ -2,41 +2,24 @@ package Hyper::Control::Base::BTree;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv('0.02');
+use version; our $VERSION = qv('0.01');
 
 use base qw(Hyper::Control::Base);
 use Class::Std::Storable;
-use Scalar::Util;
 
 my %childs_of   :ATTR(:set<childs>   :get<childs> :default<[]>);
-my %parent_of   :ATTR(:get<parent>);
-my %data_of     :ATTR(:name<data>    :default<()>);
+my %parent_of   :ATTR(:get<parent>   :set<parent>);
+my %data_of     :ATTR(:get<data>     :set<data>);
 my %position_of :ATTR(:get<position> :set<position>);
 
-sub set_parent {
-    $parent_of{ ident $_[0] } = $_[1];
-    Scalar::Util::weaken($parent_of{ ident $_[0] });
-    return $_[0];
-}
-
-sub STORABLE_thaw_post {
-    # Storable restores weak references as normal references
-    # weaken up-reference in tree after thawing
-    Scalar::Util::weaken($parent_of{ ident $_[0] })
-        if defined $parent_of{ ident $_[0] };
-
-    $_[0]->SUPER::STORABLE_thaw_post();
-}
-
 sub add_child {
     my $self  = shift;
-    my $i     = scalar @{$childs_of{ident $self}};
+    my $child = shift;
 
-    push @{$childs_of{ident $self}}, map {
-        $_->set_parent($self);
-        $_->set_position($i++);
-        $_;
-    } @_;
+    $child->set_parent($self);
+    $child->set_position(scalar @{$childs_of{ident $self}});
+
+    push @{$childs_of{ident $self}}, $child;
 
     return $self;
 }
@@ -72,16 +55,6 @@ sub get_template_childs {
         : ();
 }
 
-sub get_path {
-    my $current = shift;
-    my @path;
-
-    do {
-        my $position = $current->get_position();
-        unshift @path, $position if defined($position) or return \@path;
-    } while ( $current = $current->get_parent() );
-}
-
 1;
 
 __END__
@@ -94,7 +67,7 @@ Hyper::Control::Base::BTree - Tree Base Control
 
 =head1 VERSION
 
-This document describes Hyper::Control::Base::BTree 0.02
+This document describes Hyper::Control::Base::BTree 0.01
 
 =head1 SYNOPSIS
 
@@ -203,23 +176,23 @@ Class::Std::Storable
 
 =item Last changed by
 
-$Author: ac0v $
+$Author: $
 
 =item Id
 
-$Id: BTree.pm 526 2008-12-23 07:38:23Z ac0v $
+$Id: $
 
 =item Revision
 
-$Revision: 526 $
+$Revision: $
 
 =item Date
 
-$Date: 2008-12-23 08:38:23 +0100 (Di, 23 Dez 2008) $
+$Date: $
 
 =item HeadURL
 
-$HeadURL: http://svn.hyper-framework.org/Hyper/Hyper/trunk/lib/Hyper/Control/Base/BTree.pm $
+$HeadURL: $
 
 =back
 
