@@ -8,14 +8,14 @@ use base qw(Hyper::Control::Base);
 use Class::Std::Storable;
 
 use Hyper::Singleton::CGI;
-use File::Basename ();
+use File::Basename;
 
 sub get_filehandle {
     return Hyper::Singleton::CGI->singleton()->upload(shift->get_name());
 }
 
 sub get_filename {
-    return (split m{\\|/}, shift->get_value())[-1];
+    return (File::Basename->fileparse(shift->get_value()))[0];
 }
 
 1;
@@ -87,23 +87,23 @@ Hyper::Control::Base
 
 =item Last changed by
 
-$Author: ac0v $
+$Author: $
 
 =item Id
 
-$Id: BUpload.pm 370 2008-04-14 19:29:23Z ac0v $
+$Id: $
 
 =item Revision
 
-$Revision: 370 $
+$Revision: $
 
 =item Date
 
-$Date: 2008-04-14 21:29:23 +0200 (Mo, 14 Apr 2008) $
+$Date: $
 
 =item HeadURL
 
-$HeadURL: http://svn.hyper-framework.org/Hyper/Hyper/branches/0.04/lib/Hyper/Control/Base/BUpload.pm $
+$HeadURL: $
 
 =back
 
