@@ -2,7 +2,7 @@ package Hyper::Control::Flow;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv('1.1');
+use version; our $VERSION = qv('1.0');
 
 use base qw(Hyper::Control);
 
@@ -170,7 +170,7 @@ sub get_state_recursive {
     my %object_of = %{$self->get_objects() || {}};
     my $state     = $self->get_state();
 
-    return ( $state eq 'START' || $state eq 'END' )
+    return $state eq 'START'
         ? ()
         : [ $state,
             map {
@@ -253,7 +253,7 @@ Hyper::Control::Flow - base class for all flow and container controls
 
 =head1 VERSION
 
-This document describes Hyper::Control::Flow 1.1
+This document describes Hyper::Control::Flow 1.0
 
 =head1 SYNOPSIS
 
@@ -458,23 +458,23 @@ List::MoreUtils
 
 =item Last changed by
 
-$Author: ac0v $
+$Author: $
 
 =item Id
 
-$Id: Flow.pm 318 2008-02-16 01:57:57Z ac0v $
+$Id: $
 
 =item Revision
 
-$Revision: 318 $
+$Revision: $
 
 =item Date
 
-$Date: 2008-02-16 02:57:57 +0100 (Sa, 16 Feb 2008) $
+$Date: $
 
 =item HeadURL
 
-$HeadURL: http://svn.hyper-framework.org/Hyper/Hyper/branches/0.04/lib/Hyper/Control/Flow.pm $
+$HeadURL: $
 
 =back
 
