@@ -2,7 +2,7 @@ package Hyper::Error;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv('0.02');
+use version; our $VERSION = qv('0.01');
 
 use autouse 'Apache2::Log';
 use autouse 'Data::Dumper';
@@ -33,9 +33,7 @@ sub import {
     SET_SIGNAL_HANDLER:
     for my $name ( keys %arg_of ) {
         next SET_SIGNAL_HANDLER if ! $arg_of{$name};
-        $main::SIG{'__' . ( uc $HANDLER_OF{$name} ) . '__'}
-            = *{"CORE::GLOBAL::$HANDLER_OF{$name}"}
-            = \&_show_error_message;
+        *{"CORE::GLOBAL::$HANDLER_OF{$name}"} = \&_show_error_message;
     }
 
     return;
@@ -48,10 +46,9 @@ sub _is_eval_context {
 
 sub _show_error_message {
     # prevent from endless loops if we die internaly
-    local (*CORE::GLOBAL::die, $main::SIG{__DIE__});
+    local *CORE::GLOBAL::die;
     { no warnings qw(redefine);
-      *CORE::GLOBAL::die = $main::SIG{__DIE__}
-                         = sub { CORE::die(@_) };
+      *CORE::GLOBAL::die = sub { CORE::die(@_) };
     }
 
     my @messages        = @_;
@@ -221,7 +218,7 @@ Hyper::Error - catch die and/or warn, offers throw method
 
 =head1 VERSION
 
-This document describes Hyper::Error 0.02
+This document describes Hyper::Error 0.01
 
 =head1 SYNOPSIS
 
@@ -337,23 +334,23 @@ Readonly
 
 =item Last changed by
 
-$Author: ac0v $
+$Author: $
 
 =item Id
 
-$Id: Error.pm 522 2008-12-18 16:05:57Z ac0v $
+$Id: $
 
 =item Revision
 
-$Revision: 522 $
+$Revision: $
 
 =item Date
 
-$Date: 2008-12-18 17:05:57 +0100 (Do, 18 Dez 2008) $
+$Date: $
 
 =item HeadURL
 
-$HeadURL: http://svn.hyper-framework.org/Hyper/Hyper/branches/0.04/lib/Hyper/Error.pm $
+$HeadURL: $
 
 =back
 
